/*
 * This file is part of the xTuple ERP: PostBooks Edition, a free and
 * open source Enterprise Resource Planning software suite,
 * Copyright (c) 1999-2014 by OpenMFG LLC, d/b/a xTuple.
 * It is licensed to you under the Common Public Attribution License
 * version 1.0, the full text of which (including xTuple-specific Exhibits)
 * is available at www.xtuple.com/CPAL.  By using this software, you agree
 * to be bound by its terms.
 */

#ifndef RELATIVECALENDARITEM_H
#define RELATIVECALENDARITEM_H

#include "guiclient.h"
#include "xdialog.h"
#include <parameter.h>
#include "ui_relativeCalendarItem.h"

class relativeCalendarItem : public XDialog, public Ui::relativeCalendarItem
{
    Q_OBJECT

public:
    relativeCalendarItem(QWidget* parent = 0, const char* name = 0, bool modal = false, Qt::WindowFlags fl = 0);
    ~relativeCalendarItem();

public slots:
    virtual enum SetResponse set( const ParameterList & pParams );
    virtual void populate();
    virtual void sHandleNewOffsetType( int pOffsetType );
    virtual void sSave();

protected slots:
    virtual void languageChange();

private:
    int _mode;
    int _calitemid;
    int _calheadid;

};

#endif // RELATIVECALENDARITEM_H
